@@ -19,7 +19,7 @@ import sys
 from util import ip
 from util.cache import Cache
 
-__version__ = "v2.9.3@2020-06-28T04:44:27+00:00"  # CI 时会被Tag替换
+__version__ = "v2.9.4@2020-08-03T07:33:28+00:00"  # CI 时会被Tag替换
 __description__ = "automatically update DNS records to dynamic local IP [自动更新DNS记录指向本地IP]"
 __doc__ = """
 ddns[%s]
@@ -28,7 +28,7 @@ ddns[%s]
 Copyright (c) New Future (MIT License)
 """ % (__version__)
 
-environ["DDNS_VERSION"] = "v2.9.3"
+environ["DDNS_VERSION"] = "v2.9.4"
 
 if getattr(sys, 'frozen', False):
     # https://github.com/pyinstaller/pyinstaller/wiki/Recipe-OpenSSL-Certificate
@@ -79,13 +79,18 @@ def get_config(key=None, default=None, path="config.json"):
         return get_config.config
 
 
-def get_ip(ip_type):
+def get_ip(ip_type, index="default"):
     """
     get IP address
     """
-    index = get_config('index' + ip_type, "default")
     if index is False:  # disabled
         return False
+    elif type(index) == list:  # 如果获取到的规则是列表，则依次判断列表中每一个规则，直到找到一个可以正确获取到的IP
+        value = None
+        for i in index:
+            value = get_ip(ip_type, i)
+            if value:
+                break
     elif str(index).isdigit():  # 数字 local eth
         value = getattr(ip, "local_v" + ip_type)(index)
     elif index.startswith('cmd:'):  # cmd
@@ -129,7 +134,8 @@ def update_ip(ip_type, cache, dns, proxy_list):
     domains = get_config(ipname)
     if not domains:
         return None
-    address = get_ip(ip_type)
+    index_rule = get_config('index' + ip_type, "default")  # 从配置中获取index配置
+    address = get_ip(ip_type, index_rule)
     if not address:
         error('Fail to get %s address!' ,ipname)
         return False
